# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-05-02 10:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Movie',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(db_index=True, max_length=1024, unique=True)),
                ('external_id', models.CharField(db_index=True, max_length=2048, unique=True)),
            ],
        ),
    ]



"""Module for the management command to backfill external_id from legacy_id."""

from django.core.management.base import BaseCommand
from django.db import IntegrityError

from bomojo.movies.models import Movie

import pybomojo


class Command(BaseCommand):
    """Management command to backfill external_id from legacy_id."""

    help = 'Backfills external_id for movies that only have legacy_id'

    def handle(self, *args, **options):
        """Find all movies where external_id is null and backfill it.

        This method uses pybomojo to search for the movie by finding an exact
        title match.
        """
        movies = Movie.objects.filter(external_id__isnull=True)
        skipped = []

        for movie in movies:
            search_results = pybomojo.search_movies(movie.title)
            exact_result = next((result for result in search_results
                                 if result['exact']), None)

            if exact_result is None:
                skipped.append(movie)
                self.stdout.write('No match found for {}\n'.format(movie))
                continue

            external_id = exact_result['movie_id']
            try:
                movie.external_id = external_id
                movie.save(update_fields=['external_id'])
                self.stdout.write('{}: {}\n'.format(movie.legacy_id,
                                                    external_id))
            except IntegrityError:
                skipped.append(movie)
                self.stdout.write(
                    'Duplicate found for {}: {}\n'.format(movie, external_id))
                continue

        if skipped:
            self.stdout.write('Unable to backfill the following movies:\n')
            for movie in skipped:
                self.stdout.write('{}\n'.format(movie))



# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-01-02 11:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('movies', '0004_rename_external_id_legacy_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='movie',
            name='legacy_id',
            field=models.CharField(db_index=True, max_length=2048, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='movie',
            name='external_id',
            field=models.CharField(db_index=True, max_length=2048, null=True, unique=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-01-02 11:08
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('movies', '0003_priceindex'),
    ]

    operations = [
        migrations.RenameField(
            model_name='movie',
            old_name='external_id',
            new_name='legacy_id',
        ),
        migrations.RunSQL(
            'ALTER INDEX IF EXISTS movies_movie_external_id_key '
            'RENAME TO movies_movie_legacy_id_key',
            'ALTER INDEX IF EXISTS movies_movie_legacy_id_key '
            'RENAME TO movies_movie_external_id_key'),
        migrations.RunSQL(
            'ALTER INDEX IF EXISTS movies_movie_external_id_f11489dd_like '
            'RENAME TO movies_movie_legacy_id_like',
            'ALTER INDEX IF EXISTS movies_movie_legacy_id_like '
            'RENAME TO movies_movie_external_id_f11489dd_like')
    ]
